==> haskell-cookie-0.4.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.3
id: cookie-0.4.3-1GClGnBUUWb6JqB8uZckQR
key: cookie-0.4.3-1GClGnBUUWb6JqB8uZckQR
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.Cookie
abi: 75d39cfd15be892df6ded1ac90ba45e6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cookie-0.4.3
hs-libraries: HScookie-0.4.3-1GClGnBUUWb6JqB8uZckQR
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 time-1.8.0.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=b9d2385c579e775ca271e0b2d301ad48
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.3
id: cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c
key: cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.Cookie
abi: e060f2bc7a726f2a27d39fcbf1a51dbb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/cookie-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cookie-0.4.3
hs-libraries: HScookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 time-1.8.0.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=3962b4cebc9bc66ccf8167322740d159
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=b9d2385c579e775ca271e0b2d301ad48
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
